@@ -5,7 +5,6 @@ Classes for handling raster data.
 from . import grid
 from . import aaigrid
 from . import raster
-from . import flow
 
 from .grid import RegularGrid, WarpedGrid, aairead
 from .aaigrid import AAIGrid
@@ -27,7 +26,7 @@ try:
 except ImportError:
     pass
 
-__all__ = ["grid", "aaigrid", "raster", "flow",
+__all__ = ["grid", "aaigrid", "raster",
            "RegularGrid", "WarpedGrid", "aairead",
            "AAIGrid",
            "pad", "slope", "aspect", "grad", "div", "normed_vector_field",
