@@ -3,11 +3,11 @@ Vector data classes and functions.
 """
 
 from . import guppy
-from . import stats
 from . import xyfile
 from . import geojson
 from . import gpx
 from . import vtk
+from . import quadtree
 
 from .guppy import Point, Multipoint, Line, Polygon
 from .read import read_geojson, read_geojson_features, read_shapefile
