@@ -10,7 +10,6 @@ import math
 import sys
 import traceback
 import numpy as np
-import shapefile
 from . import vtk
 from . import geojson
 from . import xyfile
@@ -85,9 +84,10 @@ class Point(Geometry):
     _geotype = "Point"
 
     def __init__(self, coords, data=None, properties=None, **kwargs):
-        if properties is None: properties = {}
+        if properties is None:
+            properties = {}
         if not hasattr(coords, "__iter__"):
-            raise ValueError("input argument must be a sequence")
+            raise ValueError("Point coordinates must be a sequence")
         super(Point, self).__init__(**kwargs)
         self.vertex = coords
         self._setxyz()
@@ -418,19 +418,6 @@ class MultipointBase(Geometry):
         """ Return vertices as a list of tuples. """
         return np.array(self.vertices)
 
-    #def get_data(self, fields=None):
-    #    """ Return data as an array, regardless of internal type. Optionally
-    #    takes the keyword argument *fields*, which is an iterable listing the
-    #    columns from the data dictionary to retrieve. """
-    #    if hasattr(self.data, 'keys') and hasattr(self.data.values, '__call__'):
-    #        if fields is not None:
-    #            data = np.array([self.data[key] for key in fields])
-    #        else:
-    #            data = np.array(self.data.values())
-    #    else:
-    #        data = np.array(self.data)
-    #    return data.T
-
     def get_coordinate_lists(self):
         """ Return X, Y, and Z lists. If self.rank == 2, Z will be
         zero-filled. """
@@ -710,32 +697,45 @@ class ConnectedMultipoint(MultipointBase):
         return list(filter(lambda a: np.nan not in a, interx))
 
     def shortest_distance_to(self, pt):
-        """ Return the shortest distance from a point on the Multipoint
-        boundary to *pt* (Point) """
-        point_dist = map(_vecgeo.pt_nearest,
-                                [pt.vertex for seg in self.segments()],
-                                [seg[0].vertex for seg in self.segments()],
-                                [seg[1].vertex for seg in self.segments()])
+        """ Return the shortest distance from any position on the Multipoint
+        boundary to *pt* (Point).
+        """
+        if self._crs != pt._crs:
+            raise CRSError("Point must have matching CRS")
+        elif self._crs == kcrs.CARTESIAN:
+            func = _vecgeo.pt_nearest_planar
+        else:
+            func = lambda *args: _vecgeo.pt_nearest_proj(geod, *args, tol=0.01)
+
+        point_dist = map(func,
+                         [pt.vertex for seg in self.segments()],
+                         [seg[0].vertex for seg in self.segments()],
+                         [seg[1].vertex for seg in self.segments()])
         distances = [i[1] for i in point_dist]
         return min(distances)
 
     def nearest_on_boundary(self, pt):
-        """ Returns the point on the Multipoint boundary that is nearest to pt
-        (Point).
-
-        Warning: If two points are equidistant, only one will be returned.
+        """ Returns the position on the Multipoint boundary that is nearest to
+        pt (Point). If two points are equidistant, only one will be returned.
         """
-        point_dist = list(map(_vecgeo.pt_nearest,
-                                [pt.vertex for seg in self.segments()],
-                                [seg[0].vertex for seg in self.segments()],
-                                [seg[1].vertex for seg in self.segments()]))
+        if self._crs != pt._crs:
+            raise CRSError("Point must have matching CRS")
+        elif self._crs == kcrs.CARTESIAN:
+            func = _vecgeo.pt_nearest_planar
+        else:
+            func = lambda *args: _vecgeo.pt_nearest_proj(geod, *args, tol=0.01)
+
+        point_dist = list(map(func,
+                              [pt.vertex for seg in self.segments()],
+                              [seg[0].vertex for seg in self.segments()],
+                              [seg[1].vertex for seg in self.segments()]))
         distances = [i[1] for i in point_dist]
         return Point(point_dist[distances.index(min(distances))][0],
                      properties=self.properties, crs=self._crs)
 
     def within_distance(self, pt, distance):
         """ Test whether a point is within *distance* of a ConnectedMultipoint. """
-        #return distance <= self.shortest_distance_to(pt)
+        # Avoid calculating more minimum distances than necessary
         return True in (distance >= seg.shortest_distance_to(pt)
                         for seg in self.segments())
 
@@ -794,27 +794,27 @@ class Line(ConnectedMultipoint):
         """ Returns the distance between the first and last vertex. """
         return Point(self.vertices[0]).distance(Point(self.vertices[-1]))
 
-    def direction(self):
-        """ Returns a vector of the azimuth along a line at each point,
-        weighted by neighbour position. """
-        # The weights are calculated to give greater weight to azimuths to
-        # nearby points
-        # a' = w1 a1 + w2 a2
-        #    = (a1 h2) / (h1 + h2) + (a2 h1) / (h1 + h2)
-        #    = (a1 h2 + a2 h1) / (h1 + h2)
-        azs = np.empty(len(self)-1)
-        hs = np.empty(len(self)-1)
-        pts = [pt for pt in self]
-        for i in range(len(self)-1):
-            azs[i] = pt[i].azimuth(pt[i+1])
-            hs[i] = pt[i].distance(pt[i+1])
-        weighted_azs = np.empty(len(self))
-        weighted_azs[0] = azs[0]
-        weighted_azs[-1] = azs[-1]
-        for i in range(1, len(self)-1):
-            raise NotImplementedError("need to phase unwrap")
-            weighted_azs[i] = (azs[i]*hs[i+1] + azs[i+1]*hs[i]) / (hs[i] + hs[i+1])
-        return weighted_azs
+    #def direction(self):
+    #    """ Returns a vector of the azimuth along a line at each point,
+    #    weighted by neighbour position. """
+    #    # The weights are calculated to give greater weight to azimuths to
+    #    # nearby points
+    #    # a' = w1 a1 + w2 a2
+    #    #    = (a1 h2) / (h1 + h2) + (a2 h1) / (h1 + h2)
+    #    #    = (a1 h2 + a2 h1) / (h1 + h2)
+    #    azs = np.empty(len(self)-1)
+    #    hs = np.empty(len(self)-1)
+    #    pts = [pt for pt in self]
+    #    for i in range(len(self)-1):
+    #        azs[i] = pt[i].azimuth(pt[i+1])
+    #        hs[i] = pt[i].distance(pt[i+1])
+    #    weighted_azs = np.empty(len(self))
+    #    weighted_azs[0] = azs[0]
+    #    weighted_azs[-1] = azs[-1]
+    #    for i in range(1, len(self)-1):
+    #        raise NotImplementedError("need to phase unwrap")
+    #        weighted_azs[i] = (azs[i]*hs[i+1] + azs[i+1]*hs[i]) / (hs[i] + hs[i+1])
+    #    return weighted_azs
 
     def to_polygon(self):
         """ Returns a polygon. """
