@@ -18,7 +18,7 @@ class Metadata(Mapping):
     _data = {}
     _fieldtypes = []
 
-    def __init__(self, data, singleton=False):
+    def __init__(self, data, singleton=False, copydata=True):
         """ Create a collection of metadata from *data*, which may be a list
         with uniform type or a dictionary with equally-sized fields of uniform
         type.
@@ -31,11 +31,13 @@ class Metadata(Mapping):
         *kwargs*:
         singleton : treat data as a single unit, rather than as a list of units
         """
+        if copydata:
+            data = copy.deepcopy(data)
 
         if singleton:
 
             if hasattr(data, "keys") and hasattr(data.values, "__call__"):
-                self._data = data
+                    self._data = data
             elif data is not None:
                 self._data = {"values": data}
             else:
@@ -59,6 +61,7 @@ class Metadata(Mapping):
                     self._len = 0
                 else:
                     self._len = n
+                data = data
 
             elif data is not None:
                 # Single attribute
@@ -153,7 +156,7 @@ class Metadata(Mapping):
 
         for key, val in items:
             newdata[key] = [self._data[key][i] for i in idxs]
-        return Metadata(newdata)
+        return Metadata(newdata, copydata=False)
 
     def getfield(self, name):
         """ Return all values from field *name*. """
